@@ -7,14 +7,14 @@ import re
 from typing import TYPE_CHECKING, Any, List, Optional, cast
 
 from robotcode.core.logging import LoggingDescriptor
-from robotcode.language_server.common.decorators import language_id
-from robotcode.language_server.common.lsp_types import (
+from robotcode.core.lsp.types import (
     FormattingOptions,
     MessageType,
     Position,
     Range,
     TextEdit,
 )
+from robotcode.language_server.common.decorators import language_id
 from robotcode.language_server.common.text_document import TextDocument
 from robotcode.language_server.robotframework.utils.version import get_robot_version
 
